==> jdNBTExplorer-2.0.tar.gz: jdNBTExplorer-2.0/jdNBTExplorer/translations/jdNBTExplorer_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>AboutWindow</name>
    <message>
        <location filename="../ui/AboutWindow.ui" line="0"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../ui/AboutWindow.ui" line="0"/>
        <source>An editor for Minecraft NBT files</source>
        <translation>Ein Editor für Minecraft NBT Dateien</translation>
    </message>
    <message>
        <location filename="../ui/AboutWindow.ui" line="0"/>
        <source>This program is licensed under GNU GPL 3</source>
        <translation>Dieses Programm ist unter der GNU GPL 3 lizenziert</translation>
    </message>
    <message>
        <location filename="../ui/AboutWindow.ui" line="0"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>EditWindow</name>
    <message>
        <location filename="../EditWindow.py" line="55"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="../EditWindow.py" line="61"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../EditWindow.py" line="84"/>
        <source>Name can&apos;t be empty</source>
        <translation>Name darf nicht leer sein</translation>
    </message>
    <message>
        <location filename="../EditWindow.py" line="84"/>
        <source>You need to set a Name</source>
        <translation>Du musst einen Namen eingeben</translation>
    </message>
    <message>
        <location filename="../EditWindow.py" line="108"/>
        <location filename="../EditWindow.py" line="98"/>
        <location filename="../EditWindow.py" line="92"/>
        <source>Invalid Value</source>
        <translation>Ungültiger Wert</translation>
    </message>
    <message>
        <location filename="../EditWindow.py" line="108"/>
        <location filename="../EditWindow.py" line="98"/>
        <location filename="../EditWindow.py" line="92"/>
        <source>This value is not allowed for this type</source>
        <translation>Dieser Wert ist für diesen Datentyp ungültig</translation>
    </message>
    <message>
        <location filename="../ui/EditWindow.ui" line="0"/>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <location filename="../ui/EditWindow.ui" line="0"/>
        <source>Value:</source>
        <translation>Wert:</translation>
    </message>
    <message>
        <location filename="../ui/EditWindow.ui" line="0"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
</context>
<context>
    <name>Language</name>
    <message>
        <location filename="../Languages.py" line="6"/>
        <source>English</source>
        <translation>Englisch</translation>
    </message>
    <message>
        <location filename="../Languages.py" line="7"/>
        <source>German</source>
        <translation>Deutsch</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.py" line="63"/>
        <source>File not found</source>
        <translation>Datei nicht gefunden</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="63"/>
        <source>{{path}} was not found</source>
        <translation>{{path}} wurde nicht gefunden</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="75"/>
        <source>Not an NBT File</source>
        <translation>Keine NBT Datei</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="75"/>
        <source>This File does not look like an NBT File</source>
        <translation>Diese datei sieht nicht wie eine NBT Datei aus</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="100"/>
        <source>No recent files</source>
        <translation>Keine zuletzt geöffneten Dateien</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="111"/>
        <source>Clear</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="152"/>
        <source>File modified</source>
        <translation>Datei geändert</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="152"/>
        <source>The File has been modified. Do you want to save your changes?</source>
        <translation>Die Datei wurde geändert. Möchstest du die Änderungen speichern?</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="162"/>
        <source>Show this message on startup</source>
        <translation>Diese Nachricht beim Starten anzeigen</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="165"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="166"/>
        <source>jdNBTExplorer is a programme that allows you to edit Minecraft&apos;s NBT files. Using it without proper knowledge can destroy your world. Therefore, please always make a backup of your world before using it.</source>
        <translation>jdNBTExplorer ist ein Programm, mit dem du die NBT Dateien von Minecraft bearbeiten kannst. Die unbedarfte Benutzung kann deine Welt zerstören. Bitte mache daher vor der Benutzung immer ein Backup deiner Welt.</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Recent Files</source>
        <translation>Zuletzt geöffnete Dateien</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Open Directory</source>
        <translation>Verzeichnis öffnen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>New Tag</source>
        <translation>Neuer Tag</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Edit Tag</source>
        <translation>Tag bearbieten</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>New Compound</source>
        <translation>Neuer Datenverbund</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>New List</source>
        <translation>Neue Liste</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Remove</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Show Welcome Dialog</source>
        <translation>Willkommensdialog anzeigen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>View Source</source>
        <translation>Quelltext ansehen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Report Bug</source>
        <translation>Fehler melden</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Translate</source>
        <translation>Übersetzen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Donate</source>
        <translation>Spenden</translation>
    </message>
</context>
<context>
    <name>SettingsWindow</name>
    <message>
        <location filename="../SettingsWindow.py" line="24"/>
        <source>System language</source>
        <translation>Systemsprache</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Language:</source>
        <translation>Sprache:</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>(needs Restart)</source>
        <translation>(benötigt Neustart)</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Length of recent files list:</source>
        <translation>Länge der Liste der zuletzt geöffneten Dateien:</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Ask before closing unsaved Files</source>
        <translation>Vor dem Schließen ungeöffneter Dateien nachfragen</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Show welcome message on startup</source>
        <translation>Zeige Willkommensnachricht beim Starten</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>TreeWidget</name>
    <message>
        <location filename="../TreeWidget.py" line="81"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="81"/>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="81"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="122"/>
        <source>Can&apos;t read file</source>
        <translation>Konnte Datei nicht lesen</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="122"/>
        <source>Can&apos;t read {{path}}. Maybe it&apos;s not a NBT File.</source>
        <translation>Konnte {{path}} nicht lesen. Vielleicht ist es keine NBT Datei.</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="210"/>
        <source>Not supported</source>
        <translation>Nicht unterstützt</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="210"/>
        <source>Saving a region file is currently not supported</source>
        <translation>das Speichern von regionen wird aktuell nicht unterstützt</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="293"/>
        <source>New Compound</source>
        <translation>Neuer Datenverbund</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="293"/>
        <source>Please enter a name for the new compound</source>
        <translation>Bitte gib einen Namen für den neuen Datenverbund ein</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="308"/>
        <source>New List</source>
        <translation>Neue Liste</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="308"/>
        <source>Please enter a name for the new List</source>
        <translation>Bitte gib einen Namen für die neue Liste ein</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="323"/>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="323"/>
        <source>Please enter a new Name</source>
        <translation>Bitte gib einen neuen Namen ein</translation>
    </message>
</context>
</TS>

==> jdNBTExplorer-2.1.tar.gz: jdNBTExplorer-2.1/jdNBTExplorer/translations/jdNBTExplorer_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>AboutWindow</name>
    <message>
        <location filename="../ui/AboutWindow.ui" line="0"/>
        <location filename="../ui/AboutWindow.ui" line="0"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../ui/AboutWindow.ui" line="0"/>
        <source>An editor for Minecraft NBT files</source>
        <translation>Ein Editor für Minecraft NBT Dateien</translation>
    </message>
    <message>
        <location filename="../ui/AboutWindow.ui" line="0"/>
        <source>This Program is licensed under GPL 3</source>
        <translation>Dieses Programm ist unter der GPL 3 lizenziert</translation>
    </message>
    <message>
        <location filename="../ui/AboutWindow.ui" line="0"/>
        <source>Translators</source>
        <translation>Übersetzer</translation>
    </message>
    <message>
        <location filename="../ui/AboutWindow.ui" line="0"/>
        <source>The following people translated jdNBTExplorer:</source>
        <translation>Die folgenden Personen haben jdNBTExplorer übersetzt:</translation>
    </message>
    <message>
        <location filename="../ui/AboutWindow.ui" line="0"/>
        <source>Changelog</source>
        <translation>Änderungsprotokoll</translation>
    </message>
    <message>
        <location filename="../ui/AboutWindow.ui" line="0"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>EditWindow</name>
    <message>
        <location filename="../EditWindow.py" line="55"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="../EditWindow.py" line="61"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../EditWindow.py" line="84"/>
        <source>Name can&apos;t be empty</source>
        <translation>Name darf nicht leer sein</translation>
    </message>
    <message>
        <location filename="../EditWindow.py" line="84"/>
        <source>You need to set a Name</source>
        <translation>Du musst einen Namen eingeben</translation>
    </message>
    <message>
        <location filename="../EditWindow.py" line="108"/>
        <location filename="../EditWindow.py" line="98"/>
        <location filename="../EditWindow.py" line="92"/>
        <source>Invalid Value</source>
        <translation>Ungültiger Wert</translation>
    </message>
    <message>
        <location filename="../EditWindow.py" line="108"/>
        <location filename="../EditWindow.py" line="98"/>
        <location filename="../EditWindow.py" line="92"/>
        <source>This value is not allowed for this type</source>
        <translation>Dieser Wert ist für diesen Datentyp ungültig</translation>
    </message>
    <message>
        <location filename="../ui/EditWindow.ui" line="0"/>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <location filename="../ui/EditWindow.ui" line="0"/>
        <source>Value:</source>
        <translation>Wert:</translation>
    </message>
    <message>
        <location filename="../ui/EditWindow.ui" line="0"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
</context>
<context>
    <name>Language</name>
    <message>
        <location filename="../Languages.py" line="6"/>
        <source>English</source>
        <translation>Englisch</translation>
    </message>
    <message>
        <location filename="../Languages.py" line="7"/>
        <source>German</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="../Languages.py" line="8"/>
        <source>Dutch</source>
        <translation>Niederländisch</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.py" line="63"/>
        <source>File not found</source>
        <translation>Datei nicht gefunden</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="63"/>
        <source>{{path}} was not found</source>
        <translation>{{path}} wurde nicht gefunden</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="75"/>
        <source>Not an NBT File</source>
        <translation>Keine NBT Datei</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="75"/>
        <source>This File does not look like an NBT File</source>
        <translation>Diese datei sieht nicht wie eine NBT Datei aus</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="100"/>
        <source>No recent files</source>
        <translation>Keine zuletzt geöffneten Dateien</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="111"/>
        <source>Clear</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="152"/>
        <source>File modified</source>
        <translation>Datei geändert</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="152"/>
        <source>The File has been modified. Do you want to save your changes?</source>
        <translation>Die Datei wurde geändert. Möchstest du die Änderungen speichern?</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="162"/>
        <source>Show this message on startup</source>
        <translation>Diese Nachricht beim Starten anzeigen</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="165"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../MainWindow.py" line="166"/>
        <source>jdNBTExplorer is a programme that allows you to edit Minecraft&apos;s NBT files. Using it without proper knowledge can destroy your world. Therefore, please always make a backup of your world before using it.</source>
        <translation>jdNBTExplorer ist ein Programm, mit dem du die NBT Dateien von Minecraft bearbeiten kannst. Die unbedarfte Benutzung kann deine Welt zerstören. Bitte mache daher vor der Benutzung immer ein Backup deiner Welt.</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Recent Files</source>
        <translation>Zuletzt geöffnete Dateien</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Open Directory</source>
        <translation>Verzeichnis öffnen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>New Tag</source>
        <translation>Neuer Tag</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Edit Tag</source>
        <translation>Tag bearbieten</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>New Compound</source>
        <translation>Neuer Datenverbund</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>New List</source>
        <translation>Neue Liste</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Remove</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Show Welcome Dialog</source>
        <translation>Willkommensdialog anzeigen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>View Source</source>
        <translation>Quelltext ansehen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Report Bug</source>
        <translation>Fehler melden</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Translate</source>
        <translation>Übersetzen</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="0"/>
        <source>Donate</source>
        <translation>Spenden</translation>
    </message>
</context>
<context>
    <name>SettingsWindow</name>
    <message>
        <location filename="../SettingsWindow.py" line="24"/>
        <source>System language</source>
        <translation>Systemsprache</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Language:</source>
        <translation>Sprache:</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>(needs Restart)</source>
        <translation>(benötigt Neustart)</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Length of recent files list:</source>
        <translation>Länge der Liste der zuletzt geöffneten Dateien:</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Ask before closing unsaved Files</source>
        <translation>Vor dem Schließen ungeöffneter Dateien nachfragen</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Show welcome message on startup</source>
        <translation>Zeige Willkommensnachricht beim Starten</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../ui/SettingsWindow.ui" line="0"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>TreeWidget</name>
    <message>
        <location filename="../TreeWidget.py" line="81"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="81"/>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="81"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="122"/>
        <source>Can&apos;t read file</source>
        <translation>Konnte Datei nicht lesen</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="122"/>
        <source>Can&apos;t read {{path}}. Maybe it&apos;s not a NBT File.</source>
        <translation>Konnte {{path}} nicht lesen. Vielleicht ist es keine NBT Datei.</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="210"/>
        <source>Not supported</source>
        <translation>Nicht unterstützt</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="210"/>
        <source>Saving a region file is currently not supported</source>
        <translation>das Speichern von regionen wird aktuell nicht unterstützt</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="293"/>
        <source>New Compound</source>
        <translation>Neuer Datenverbund</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="293"/>
        <source>Please enter a name for the new compound</source>
        <translation>Bitte gib einen Namen für den neuen Datenverbund ein</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="308"/>
        <source>New List</source>
        <translation>Neue Liste</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="308"/>
        <source>Please enter a name for the new List</source>
        <translation>Bitte gib einen Namen für die neue Liste ein</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="323"/>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <location filename="../TreeWidget.py" line="323"/>
        <source>Please enter a new Name</source>
        <translation>Bitte gib einen neuen Namen ein</translation>
    </message>
</context>
</TS>
